geomancy-0.3.0.0: Vectors and matrix manipulation
Safe HaskellNone
LanguageHaskell2010

Geomancy.Vulkan.View

Synopsis

Documentation

lookAtRH Source #

Arguments

:: Vec3

Eye position

-> Vec3

Target

-> Vec3

Up direction

-> Transform 

Construct a right-handed world-to-view transformation.

This will rotate and translate the world around a static camera. This would produce an identity when looking from vec3 0 0 0 to vec3 0 0 1 using (-Y up).

The fallback "up" should be used when you're looking close to your UP in either direction.

lookAtRH_ :: Vec3 -> Vec3 -> Transform Source #

A shortcut for using the -Y as the up axis.

Looking forward from the origin does nothing.